@@ -1,5 +1,6 @@
 import io
 import json
+import os
 
 
 class JsonSerializable:
@@ -13,11 +14,11 @@ class JsonSerializable:
             setattr(output, name, dic.get(name))
         return output
 
-    def to_json(self, f=None):
+    def to_json(self, f=None, encoding=None):
         if f is None:
             return json.dumps(self.to_dict())
         elif isinstance(f, str):
-            with open(f, "w") as f:
+            with open(f, "w", encoding=encoding) as f:
                 return json.dump(self.to_dict(), f)
         elif isinstance(f, io.TextIOBase):
             return json.dump(self.to_dict(), f)
@@ -25,9 +26,15 @@ class JsonSerializable:
             raise ValueError("Unsupported argument type: %s" % type(f))
 
     @classmethod
-    def from_json(cls, jsn):
+    def from_json(cls, jsn, encoding=None):
         if isinstance(jsn, str):
-            dic = json.loads(jsn)
+            if jsn.startswith("{") and jsn.endswith("}"):
+                dic = json.loads(jsn)
+            elif os.path.exists(jsn):
+                with open(jsn, "r", encoding=encoding) as f:
+                    dic = json.load(f)
+            else:
+                dic = json.loads(jsn)
         elif isinstance(jsn, io.TextIOBase):
             dic = json.load(jsn)
         else:
